# Textual-MQTT, a Textual wrapper over Paho MQTT

[![PyPI - Version](https://img.shields.io/pypi/v/textual-mqtt.svg)](https://pypi.org/project/textual-mqtt)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/textual-mqtt.svg)](https://pypi.org/project/textual-mqtt)

-----

Textual is a TUI Python framework using asyncio for interface processing. Paho MQTT uses it's own threads, making some operations (callbacks, specially) not completely straight-forward. This library implements Textual widgets to integrate Paho MQTT into the built-in messaging system.

## Installation

```console
pip install textual-mqtt
```

## License

`textual-mqtt` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
